@@ -188,11 +188,6 @@ class WbUrl(BaseWbUrl):
             else:
                 return url
 
-    @property
-    def is_mainpage(self):
-        return (not self.mod or
-                self.mod == 'mp_')
-
     @property
     def is_top_frame(self):
         return (self.mod == 'tf_')
