@@ -1,7 +1,7 @@
 /*
 Copyright(c) 2013-2014 Ilya Kreymer. Released under the GNU General Public License.
 
-This file is part of pywb.
+This file is part of pywb, https://github.com/ikreymer/pywb
 
     pywb is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -17,12 +17,7 @@ This file is part of pywb.
     along with pywb.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-_wb_js = (function() {
-
-
-var labels = {LOADING_MSG: "Loading...",
-              REPLAY_MSG: "This is an <b>archived</b> page from ",
-              LIVE_MSG: "This is a <b>live</b> page loaded on "};
+function __WbJsInit() {
 
 
 function init_banner() {
@@ -40,49 +35,23 @@ function init_banner() {
         bid = PLAIN_BANNER_ID;
     }
 
-    var banner = document.getElementById(bid);
-    
-    if (banner) {
+    if (document.getElementById(bid) != null) {
         return;
     }
-        
-    banner = document.createElement("wb_div");
-    banner.setAttribute("id", bid);
-    banner.setAttribute("lang", "en");
-
-    var text;
-
-    if (wbinfo.is_frame) {
-        text = labels.LOADING_MSG;
-    } else if (wbinfo.is_live) {
-        text = labels.LIVE_MSG;
-    } else {
-        text = labels.REPLAY_MSG;
-    }
     
-    text = "<span id='_wb_label'>" + text + "</span>";
-
-    var capture_str = "";
-    if (wbinfo && wbinfo.timestamp) {
-        capture_str = ts_to_date(wbinfo.timestamp, true);
-    }
-
-    text += "<b id='_wb_capture_info'>" + capture_str + "</b>";
-
-    if (wbinfo.proxy_magic && wbinfo.url) {
-        var select_url = wbinfo.proxy_magic + "/" + wbinfo.url;
-        var query_url = wbinfo.proxy_magic + "/*/" + wbinfo.url;
-        text += '&nbsp;<a href="//query.' + query_url + '">All Capture Times</a>';
-        text += '<br/>'
-        text += 'From collection <b>"' + wbinfo.coll + '"</b>&nbsp;<a href="//select.' + select_url + '">All Collections</a>';
-    }
-    
-    banner.innerHTML = text;
-
-    document.body.insertBefore(banner, document.body.firstChild);
+    _wb_js.create_banner_element(bid);
 }
 
-function ts_to_date(ts, is_gmt)
+this.banner_labels = {LOADING_MSG: "Loading...",
+                      REPLAY_MSG: "This is an <b>archived</b> page from ",
+                      LIVE_MSG: "This is a <b>live</b> page loaded on "};
+
+this.create_banner_element = function() {
+    // No banner by default
+    return null;
+}
+
+this.ts_to_date = function(ts, is_gmt)
 {
     if (ts.length < 14) {
         return ts;
@@ -147,22 +116,21 @@ function notify_top() {
     remove_event("readystatechange", notify_top, document);
 }
 
-if ((window.self == window.top) && wbinfo) {
-    if (wbinfo.canon_url && (window.location.href != wbinfo.canon_url) && wbinfo.mod != "bn_") {
-        // Auto-redirect to top frame
-        window.location.replace(wbinfo.canon_url);
-    } else {
-        // Init Banner (no frame or top frame)
-        add_event("readystatechange", init_banner, document);
+this.load = function() {
+    if ((window.self == window.top) && wbinfo) {
+        if (wbinfo.top_url && (window.location.href != wbinfo.top_url) && wbinfo.mod != "bn_") {
+            // Auto-redirect to top frame
+            window.location.replace(wbinfo.top_url);
+        } else {
+            // Init Banner (no frame or top frame)
+            add_event("readystatechange", init_banner, document);
+        }
+    } else if (window.self != window.parent && window.parent.update_wb_url) {
+        add_event("readystatechange", notify_top, document);
     }
-} else if (window.self != window.parent && window.parent.update_wb_url) {
-    add_event("readystatechange", notify_top, document);
 }
 
+};
 
-return {
-        'labels': labels,
-        'ts_to_date': ts_to_date
-       };
 
-})();
+_wb_js = new __WbJsInit();
